@@ -1,5 +1,6 @@
 import asyncio
 import functools
+import logging
 import socket
 import time
 from concurrent.futures.thread import ThreadPoolExecutor
@@ -9,12 +10,11 @@ import requests
 from django.conf import settings
 from requests import RequestException
 
-from hurricane.server.loggers import logger
-
 
 class WebhookStatus(Enum):
     FAILED = "failed"
     SUCCEEDED = "succeeded"
+    WARNING = "warning"
 
 
 class Webhook:
@@ -36,11 +36,11 @@ class Webhook:
         Getting webhook from registry using the code.
         """
 
-        from hurricane.metrics import registry
+        from hurricane.webhooks import webhook_registry
 
-        return registry.get(cls.code)
+        return webhook_registry.get(cls.code)
 
-    def run(self, url: str, status: WebhookStatus, error_trace: str = None, close_loop: bool = False):
+    def run(self, url: str, status: WebhookStatus, error_trace: str = None, close_loop: bool = False, loop=None):
 
         """
         Initiates the sending of webhook in an asynchronous manner. Also specifies the callback of the async process,
@@ -55,20 +55,24 @@ class Webhook:
         close_loop : specifies, whether the main loop should be closed or be left running
         """
 
-        self.set_traceback(error_trace)
-        self.set_status(status)
-        self.set_timestamp()
-        self.set_podname()
-        self.set_version()
-        current_loop = asyncio.get_event_loop()
-        executor = ThreadPoolExecutor(max_workers=1)
-        fut = current_loop.run_in_executor(executor, self._send_webhook, self.get_message(), url, close_loop)
-        # callback runs after run_in_executor is done
-        callback_wrapper = functools.partial(self._callback_webhook_exception_check, url=url, close_loop=close_loop)
-        fut.add_done_callback(callback_wrapper)
+        if url:
+            self.set_traceback(error_trace)
+            self.set_status(status)
+            self.set_timestamp()
+            self.set_podname()
+            self.set_version()
+            current_loop = loop or asyncio.get_event_loop()
+            executor = ThreadPoolExecutor(max_workers=1)
+            fut = current_loop.run_in_executor(executor, self._send_webhook, self.get_message(), url, close_loop)
+            # callback runs after run_in_executor is done
+            callback_wrapper = functools.partial(
+                self._callback_webhook_exception_check, url=url, close_loop=close_loop, loop=loop
+            )
+            fut.add_done_callback(callback_wrapper)
 
     def _send_webhook(self, data: dict, webhook_url: str, close_loop: bool):
         # sending webhook request to the specified url
+        logger = logging.getLogger()
         logger.info(f"Start sending {self.code} webhook to {webhook_url}")
 
         response = requests.post(webhook_url, timeout=5, json=data)
@@ -96,9 +100,10 @@ class Webhook:
         return self.data
 
     @staticmethod
-    def _callback_webhook_exception_check(future: asyncio.Future, url: str, close_loop: bool):
+    def _callback_webhook_exception_check(future: asyncio.Future, url: str, close_loop: bool, loop=None):
         # checks if sending webhook had any failures, it indicates, that command was successfully executed
         # but sending webhook has failed
+        logger = logging.getLogger()
         try:
             future.result()
         except RequestException as e:
@@ -106,5 +111,4 @@ class Webhook:
 
         if close_loop:
             logger.info("Loop will be closed")
-            current_loop = asyncio.get_event_loop()
-            current_loop.stop()
+            loop.stop()
